@@ -621,7 +621,7 @@ def _syncuser(username, hubname = "", syncAttributes = False):
 	attrsToSync = {}
 	if syncAttributes:
 
-		attributesToCheck = ['userPassword', 'shadowLastChange', 'shadowMin', 'shadowMax', 'shadowWarning', 'shadowInactive', 'shadowExpire', 'shadowFlag']
+		attributesToCheck = ['loginShell', 'userPassword', 'shadowLastChange', 'shadowMin', 'shadowMax', 'shadowWarning', 'shadowInactive', 'shadowExpire', 'shadowFlag']
 		
 		# set all the attributes
 		for a in attributesToCheck:
